@@ -1,7 +1,10 @@
 var group__act =
 [
-    [ "Mirror and Redirect", "group__act__mirred.html", null ],
-    [ "SKB Editing", "group__act__skbedit.html", null ],
+    [ "GACT Editing", "group__act__gact.html", "group__act__gact" ],
+    [ "Mirror and Redirect", "group__act__mirred.html", "group__act__mirred" ],
+    [ "NAT", "group__act__nat.html", "group__act__nat" ],
+    [ "SKB Editing", "group__act__skbedit.html", "group__act__skbedit" ],
+    [ "VLAN Manipulation", "group__act__vlan.html", "group__act__vlan" ],
     [ "rtnl_act_build_add_request", "group__act.html#ga2417f1562b63c30e7e837637a8df1723", null ],
     [ "rtnl_act_add", "group__act.html#gaf8701292660673088fa96fdd2eed5829", null ],
     [ "rtnl_act_build_change_request", "group__act.html#gafeb36da650f53137fce994cbccef4521", null ],
