@@ -4,13 +4,15 @@ var group__class =
     [ "Differentiated Services Marker (DSMARK)", "group__qdisc__dsmark.html", "group__qdisc__dsmark" ],
     [ "Hierachical Token Bucket (HTB)", "group__qdisc__htb.html", "group__qdisc__htb" ],
     [ "Hierarchical Fair Service Curve (HFSC)", "group__qdisc__hfsc.html", "group__qdisc__hfsc" ],
+    [ "rtnl_class", "structrtnl__class.html", null ],
     [ "rtnl_class_build_add_request", "group__class.html#ga6a6c17af38a79416ae416ae23fa9239f", null ],
     [ "rtnl_class_add", "group__class.html#ga2ee0c64f6fc7bd5e15fafcd75783a3d1", null ],
     [ "rtnl_class_build_delete_request", "group__class.html#ga3c7998cb06cc00ea3cc289601592cea3", null ],
     [ "rtnl_class_delete", "group__class.html#gab9eae6965dd1b45d6984b25542ef3e5d", null ],
-    [ "rtnl_class_leaf_qdisc", "group__class.html#ga6f1e82f7440284058b7c690a66698645", null ],
+    [ "rtnl_class_leaf_qdisc", "group__class.html#ga0f5bcacde4b787bad7783c0da67c42fd", null ],
     [ "rtnl_class_alloc_cache", "group__class.html#gabec7c7469fda31138f5ba7f11776acd2", null ],
-    [ "rtnl_class_get", "group__class.html#gab3d35399a55a9a44b6d68f516bae2548", null ],
+    [ "rtnl_class_get", "group__class.html#ga839ab4e9a48886923dea7134a05065b2", null ],
+    [ "rtnl_class_get_by_parent", "group__class.html#ga3e51cd420c2dd84718d02b5f22adc00f", null ],
     [ "rtnl_class_foreach_child", "group__class.html#gad0aec75779149aad52b96dbae8a15826", null ],
     [ "rtnl_class_foreach_cls", "group__class.html#gab7db6ce58ceab5eab2e47880d69f965d", null ]
 ];
\ No newline at end of file
