@@ -3,6 +3,7 @@ var group__cli =
     [ "Addresses", "group__cli__addr.html", null ],
     [ "Classifiers", "group__cli__cls.html", null ],
     [ "Connection Tracking", "group__cli__ct.html", null ],
+    [ "Expectation Tracking", "group__cli__exp.html", null ],
     [ "Links", "group__cli__link.html", null ],
     [ "Neighbour", "group__cli__neigh.html", null ],
     [ "Queueing Disciplines", "group__cli__qdisc.html", null ],
@@ -10,6 +11,7 @@ var group__cli =
     [ "Routing Rules", "group__cli__rule.html", null ],
     [ "Traffic Classes", "group__cli__class.html", null ],
     [ "Traffic Control", "group__cli__tc.html", null ],
+    [ "nhs", "group__cli__nh.html", null ],
     [ "nl_cli_parse_u32", "group__cli.html#gaab66b72df11e32668df817475683b139", null ],
     [ "nl_cli_fatal", "group__cli.html#ga6eb1ac48798f073c336d918eaa88e34c", null ]
 ];
\ No newline at end of file
