@@ -1,14 +1,6 @@
 var group__ip6vti =
 [
-    [ "ip6vti_info", "structip6vti__info.html", [
-      [ "link", "group__ip6vti.html#ga4efca6ffc2787127c973dc2f48ff8bf6", null ],
-      [ "ikey", "group__ip6vti.html#ga73fa4f4259096b4295d67388320c8460", null ],
-      [ "okey", "group__ip6vti.html#ga2d7dd0c79d2a73f10ba7244cb52649cf", null ],
-      [ "local", "group__ip6vti.html#ga66c78535e578568a0b498c79c4c9031f", null ],
-      [ "remote", "group__ip6vti.html#ga6cba1e0c599f69739a0989a28d676ed1", null ],
-      [ "fwmark", "group__ip6vti.html#ga1e37324f6714ff722fb91ad428c95865", null ],
-      [ "ip6vti_mask", "group__ip6vti.html#ga36566410cdeb2894cb3aa678f4c6ffdf", null ]
-    ] ],
+    [ "ip6vti_info", "structip6vti__info.html", null ],
     [ "rtnl_link_is_ip6vti", "group__ip6vti.html#ga93aeb5ea686491816fb78e6b0156961a", null ],
     [ "rtnl_link_ip6vti_add", "group__ip6vti.html#ga1581d3dceb222c0e088fe99f626d08e7", null ],
     [ "rtnl_link_ip6vti_set_link", "group__ip6vti.html#ga6c8f504a6a7016a594d4ae0d432396d0", null ],
