@@ -1,13 +1,19 @@
 var group__macvlan =
 [
-    [ "rtnl_link_macvlan_alloc", "group__macvlan.html#gafcc34f43c45fa783f17929ee7f118c4b", null ],
+    [ "rtnl_link_macvlan_alloc", "group__macvlan.html#ga40edc3668501ca94a78e17c7073defcc", null ],
     [ "rtnl_link_is_macvlan", "group__macvlan.html#gab7be7201e14ad10cb687d567e01560d7", null ],
     [ "rtnl_link_macvlan_set_mode", "group__macvlan.html#ga33d87dd5ebb6cd563718a940232cab59", null ],
     [ "rtnl_link_macvlan_get_mode", "group__macvlan.html#ga82fcec0148eca72dda3f8e92b1c74e6a", null ],
+    [ "rtnl_link_macvlan_set_macmode", "group__macvlan.html#ga8d531ea6bfb4f731c4dfb02ccd4439ae", null ],
+    [ "rtnl_link_macvlan_get_macmode", "group__macvlan.html#ga0eb62859b9b139a2b115095d9f5d8271", null ],
     [ "rtnl_link_macvlan_set_flags", "group__macvlan.html#gaa751922f91e25bdabf50cf127f38a18c", null ],
     [ "rtnl_link_macvlan_unset_flags", "group__macvlan.html#ga239a6dba9bb364bdddd6d2b80ad7c005", null ],
     [ "rtnl_link_macvlan_get_flags", "group__macvlan.html#gab7a045cf96a6d22afe89393aaa8a43f5", null ],
-    [ "rtnl_link_macvtap_alloc", "group__macvlan.html#ga76e4ffe19e0e89a452189203691f98d4", null ],
+    [ "rtnl_link_macvlan_count_macaddr", "group__macvlan.html#gac208279459a03f4a5f4e8b43afe5c96f", null ],
+    [ "rtnl_link_macvlan_get_macaddr", "group__macvlan.html#gaa5584a19544611e6f3e5c1eb8d3d5893", null ],
+    [ "rtnl_link_macvlan_add_macaddr", "group__macvlan.html#gabc594b205d60a490f3f461bc65b3439a", null ],
+    [ "rtnl_link_macvlan_del_macaddr", "group__macvlan.html#gaaa3cda0e75c423af6f413301589b08e6", null ],
+    [ "rtnl_link_macvtap_alloc", "group__macvlan.html#gac1dc2a07756e53ef68e1dcea05f63327", null ],
     [ "rtnl_link_is_macvtap", "group__macvlan.html#ga195cda84cc1bbb990a37c359419b76e9", null ],
     [ "rtnl_link_macvtap_set_mode", "group__macvlan.html#ga4b80383e432bf1873e8b6621994807a2", null ],
     [ "rtnl_link_macvtap_get_mode", "group__macvlan.html#ga3b52e133cae3a6e5013ae8efc2e77a99", null ],
